# Factors
A new library to handle all sorts of mathematical factors of a number. From finding sum of factors to finding prime factors.
Number of built-in functions added for the library are:
nfact()     -> Finding the number of factors for the given number. Returns 'None' if there's no factor for the number else returns the number of factors.
sfact()     -> Finding the sum of factors for the given number. Returns -1 if there's no factor for the number else returns the sum of factors.
fact()      -> Gives the list of factors for the given number, returns -1 if there's no factor for the number.
efact()     -> Gives the list of even factors for the given number, returns -1 if there's no factor for the number.
ofact()     -> Gives the list of odd factors for the given number, returns -1 if there's no factor for the number.
pfact()     -> Gives the list of prime factors for the given number, returns -1 if there's no factor for the number.
sum_efact() -> Returns the sum of even factors for the given number, returns -1 if there's no factor for the number.
sum_ofact() -> Returns the sum of odd factors for the given number, returns -1 if there's no factor for the number.
sum_pfact() -> Returns the sum of prime factors for the given number, returns -1 if there's no factor for the number.

A Sample program added to show the results. Users can give number of their own choice.
